@@ -58,7 +58,6 @@ clearlooks_inverted_draw_inset (cairo_t *cr, const ClearlooksColors *colors, int
 	if (corners & CR_CORNER_BOTTOMRIGHT)
 		bot_x2 = width-radius+1;
 	
-#ifdef CAIRO_STROKE_IS_FAST
 	cairo_set_line_width (cr, 1);
 	cairo_set_source_rgba (cr, shadow.r, shadow.g, shadow.b, 0.05);
 	cairo_move_to (cr, top_x1, 0.0);
@@ -69,15 +68,6 @@ clearlooks_inverted_draw_inset (cairo_t *cr, const ClearlooksColors *colors, int
 	cairo_move_to (cr, bot_x1, height);
 	cairo_line_to (cr, bot_x2, height);
 	cairo_stroke (cr);
-#else
-	cairo_set_source_rgba (cr, shadow.r, shadow.g, shadow.b, 0.05);
-	cairo_rectangle (cr, top_x1 - 0.5, -0.5, top_x2 - top_x1 + 1, 1.0);
-	cairo_fill (cr);
-	
-	cairo_set_source_rgba (cr, hilight.r, hilight.g, hilight.b, 0.5);
-	cairo_rectangle (cr, bot_x1 - 0.5, height - 0.5, bot_x2 - bot_x1 + 1, 1.0);
-	cairo_fill (cr);
-#endif
 }
 
 static void
@@ -165,7 +155,6 @@ clearlooks_inverted_draw_button (cairo_t *cr,
 	if (!params->active)
 	{
 		cairo_pattern_t *pattern;
-		gdouble shade_size = ((100.0/height)*10.0)/100.0; /* 10 pixels */
 
 		CairoColor top_shade, bottom_shade;
 		ge_shade_color (fill, 0.95, &top_shade);		
@@ -419,13 +408,14 @@ clearlooks_inverted_draw_menuitem (cairo_t *cr,
 {
 	CairoColor *fill = (CairoColor*)&colors->spot[1];
 	CairoColor fill_shade;
-	CairoColor *border = (CairoColor*)&colors->spot[2];
+	CairoColor border = (CairoColor)colors->spot[2];
 	cairo_pattern_t *pattern;
 
+	ge_shade_color (&border, 1.05, &border);
 	ge_shade_color (fill, 0.85, &fill_shade);
 	cairo_set_line_width (cr, 1.0);
 
-	cairo_rectangle (cr, x+0.5, y+0.5, width - 1, height - 1);
+	ge_cairo_rounded_rectangle (cr, x+0.5, y+0.5, width - 1, height - 1, widget->radius, widget->corners);
 
 	pattern = cairo_pattern_create_linear (x, y, x, y + height);
 	cairo_pattern_add_color_stop_rgb (pattern, 0, fill_shade.r, fill_shade.g, fill_shade.b);
@@ -435,7 +425,7 @@ clearlooks_inverted_draw_menuitem (cairo_t *cr,
 	cairo_fill_preserve  (cr);
 	cairo_pattern_destroy (pattern);
 
-	ge_cairo_set_color (cr, border);
+	ge_cairo_set_color (cr, &border);
 	cairo_stroke (cr);
 }
 
@@ -447,9 +437,10 @@ clearlooks_inverted_draw_menubaritem (cairo_t *cr,
 {
 	CairoColor *fill = (CairoColor*)&colors->spot[1];
 	CairoColor fill_shade;
-	CairoColor *border = (CairoColor*)&colors->spot[2];
+	CairoColor border = (CairoColor)colors->spot[2];
 	cairo_pattern_t *pattern;
 	
+	ge_shade_color (&border, 1.05, &border);
 	ge_shade_color (fill, 0.85, &fill_shade);
 	
 	cairo_set_line_width (cr, 1.0);
@@ -463,7 +454,7 @@ clearlooks_inverted_draw_menubaritem (cairo_t *cr,
 	cairo_fill_preserve  (cr);
 	cairo_pattern_destroy (pattern);
 
-	ge_cairo_set_color (cr, border);
+	ge_cairo_set_color (cr, &border);
 	cairo_stroke_preserve (cr);
 }
 
@@ -742,7 +733,6 @@ clearlooks_inverted_draw_list_view_header (cairo_t *cr,
 	const CairoColor *fill = &colors->bg[params->state_type];
 	CairoColor      *border = (CairoColor*)&colors->shade[4];
 	cairo_pattern_t *pattern;
-	CairoColor *dark   = (CairoColor*)&colors->shade[3];
 	CairoColor hilight_header;
 	CairoColor hilight;
 	CairoColor shadow;
@@ -811,7 +801,7 @@ clearlooks_inverted_draw_scrollbar_stepper (cairo_t *cr,
 {
 	CairoCorners corners = CR_CORNER_NONE;
 	CairoColor border;
-	CairoColor  s1, s2, s3, s4;
+	CairoColor  s1, s2, s3;
 	cairo_pattern_t *pattern;
 	ShadowParameters shadow;
 	double radius = MIN (widget->radius, MIN ((width - 2.0) / 2.0, (height - 2.0) / 2.0));
@@ -906,7 +896,7 @@ clearlooks_inverted_draw_scrollbar_slider (cairo_t *cr,
 		CairoColor *border  = (CairoColor*)&colors->shade[8];
 		CairoColor  fill    = scrollbar->color;
 		CairoColor  hilight;
-		CairoColor  shade1, shade2, shade3, shade4;
+		CairoColor  shade1, shade2, shade3;
 		cairo_pattern_t *pattern;
 				
 		if (widget->prelight)
@@ -915,14 +905,13 @@ clearlooks_inverted_draw_scrollbar_slider (cairo_t *cr,
 		cairo_set_line_width (cr, 1);
 		
 		ge_shade_color (&fill, 1.3, &hilight);
-		ge_shade_color (&fill, 1.14, &shade1);
-		ge_shade_color (&fill, 1.04, &shade2);
-		ge_shade_color (&fill, 0.84, &shade3);
-		ge_shade_color (&fill, 0.94, &shade4);
+		ge_shade_color (&fill, 1.1, &shade1);
+		ge_shade_color (&fill, 1.05, &shade2);
+		ge_shade_color (&fill, 0.98, &shade3);
 		
 		pattern = cairo_pattern_create_linear (1, 1, 1, height-2);
-		cairo_pattern_add_color_stop_rgb (pattern, 0,    shade3.r, shade3.g, shade3.b);
-		cairo_pattern_add_color_stop_rgb (pattern, 0.5,  shade4.r, shade4.g, shade4.b);
+		cairo_pattern_add_color_stop_rgb (pattern, 0,    fill.r,  fill.g,  fill.b);
+		cairo_pattern_add_color_stop_rgb (pattern, 0.5,  shade3.r, shade3.g, shade3.b);
 		cairo_pattern_add_color_stop_rgb (pattern, 0.5,  shade2.r, shade2.g, shade2.b);	
 		cairo_pattern_add_color_stop_rgb (pattern, 1.0,  shade1.r, shade1.g, shade1.b);
 		cairo_rectangle (cr, 1, 1, width-2, height-2);
@@ -939,7 +928,7 @@ clearlooks_inverted_draw_scrollbar_slider (cairo_t *cr,
 	else
 	{
 		CairoColor border;
-		CairoColor s1, s2, s3, s4;		
+		CairoColor s1, s2, s3;
 		cairo_pattern_t *pattern;
 		int bar_x, i;
 		
