@@ -121,13 +121,14 @@ clearlooks_style_draw_shadow (DRAW_ARGS)
 	CHECK_ARGS
 	SANITIZE_SIZE
 
-	if (DETAIL ("entry") && !(widget && widget->parent && GE_IS_TREE_VIEW (widget->parent)))
+	if ((DETAIL ("entry") && !(widget && widget->parent && GE_IS_TREE_VIEW (widget->parent))) ||
+	    (DETAIL ("frame") && ge_is_in_combo_box (widget)))
 	{
 		WidgetParameters params;
 		
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
-		
-		if (widget && (ge_is_in_combo_box(widget) || GE_IS_SPIN_BUTTON (widget)))
+
+		if (widget && (ge_is_in_combo_box (widget) || GE_IS_SPIN_BUTTON (widget)))
 		{
 			width += style->xthickness;
 			if (!params.ltr)
@@ -1036,41 +1037,39 @@ clearlooks_style_draw_arrow (GtkStyle  *style,
 {
 	ClearlooksStyle  *clearlooks_style = CLEARLOOKS_STYLE (style);
 	ClearlooksColors *colors = &clearlooks_style->colors;
+	WidgetParameters params;
+	ArrowParameters  arrow;
 	cairo_t *cr = ge_gdk_drawable_to_cairo (window, area);
-		
+
 	SANITIZE_SIZE
 
-  if (arrow_type == (GtkArrowType)4) { /* NONE - new in GTK 2.10 */
+	if (arrow_type == GTK_ARROW_NONE) {
 		cairo_destroy (cr);
 		return;
 	}
 
-	if (DETAIL ("arrow"))
+	clearlooks_set_widget_parameters (widget, style, state_type, &params);
+	arrow.type = CL_ARROW_NORMAL;
+	arrow.direction = (ClearlooksDirection)arrow_type;
+	
+	if (ge_is_combo_box (widget, FALSE) && !ge_is_combo_box_entry (widget))
 	{
-		WidgetParameters params;
-		ArrowParameters  arrow;
-		
-		clearlooks_set_widget_parameters (widget, style, state_type, &params);
-		arrow.type = CL_ARROW_NORMAL;
-		arrow.direction = (ClearlooksDirection)arrow_type;
-			
-    if (ge_is_combo_box (widget, FALSE) && !ge_is_combo_box_entry (widget)) 	 
-    { 	 
-            arrow.type = CL_ARROW_COMBO; 	 
-            y -= 2; 	 
-            height += 4; 	 
-            x += 1; 	 
-    }
-		
-		STYLE_FUNCTION(draw_arrow) (cr, colors, &params, &arrow, x, y, width, height);
+		arrow.type = CL_ARROW_COMBO;
 	}
-	else
+	
+	/* I have no idea why, but the arrow of GtkCombo is larger than in other places.
+	 * Subtracting 3 seems to fix this. */
+	if (widget && widget->parent && GE_IS_COMBO (widget->parent->parent))
 	{
-		clearlooks_parent_class->draw_arrow (style, window, state_type, shadow, area,
-		                          widget, detail, arrow_type, fill,
-		                          x, y, width, height);
+		if (params.ltr)
+			x += 1;
+		else
+			x += 2;
+		width -= 3;
 	}
 	
+	STYLE_FUNCTION(draw_arrow) (cr, colors, &params, &arrow, x, y, width, height);
+	
 	cairo_destroy (cr);
 }
 
@@ -1124,6 +1123,7 @@ clearlooks_style_realize (GtkStyle * style)
 	
 	for (i=0; i<5; i++)
 	{
+		ge_gdk_color_to_cairo (&style->fg[i], &clearlooks_style->colors.fg[i]);
 		ge_gdk_color_to_cairo (&style->bg[i], &clearlooks_style->colors.bg[i]);
 		ge_gdk_color_to_cairo (&style->base[i], &clearlooks_style->colors.base[i]);
 		ge_gdk_color_to_cairo (&style->text[i], &clearlooks_style->colors.text[i]);
@@ -1244,6 +1244,7 @@ clearlooks_style_copy (GtkStyle * style, GtkStyle * src)
 	cl_style->has_scrollbar_color = cl_src->has_scrollbar_color;
 	cl_style->animation           = cl_src->animation;
 	cl_style->radius              = cl_src->radius;
+	cl_style->style               = cl_src->style;
 	
 	clearlooks_parent_class->copy (style, src);
 }
